# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image 
#                        pour la Santé)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
#
#  This software is governed by the CeCILL-B license under French law and 
#  abiding by the rules of distribution of free software. You can  use, 
#  modify and/ or redistribute the software under the terms of the CeCILL-B 
#  license as circulated by CEA, CNRS and INRIA at the following URL 
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability. 
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------  


#!/bin/bash

# Set all local variables

 if [ -f $PWD/scripts/CreaTools-configure.sh ]
 then 
   source $PWD/scripts/CreaTools-configure.sh
   source $PWD/scripts/CreaTools-names.sh

   echo "------"
   echo $PWD/scripts/CreaTools-configure.sh
   echo --generationdir--
   echo $generationdir
   echo --docgeneration--
   echo $docgeneration
   echo --installPrefix--
   echo $installPrefix
   echo --buildType--
   echo $buildType
   echo --gdcmVersion--
   echo $gdcmVersion
   echo "--ETC_BASHRC--"
   echo $ETC_BASHRC
   echo --sourcesFrom--
   echo $sourcesFrom
   echo --scriptDir--
   echo $scriptDir
   echo --start_point--
   echo $start_point
   echo "------"

else
   echo
   echo "..ERROR.."
   echo "==================================================="
   echo "REMEMBER !"
   echo ""
   echo "YOU NEED TO RUN 'Configure' (0) First !"
   echo "==================================================="
   echo
   echo
   exit 0

fi

if [ ! -e $generationdir ]
then
   mkdir -p $generationdir
   mkdir -p $generationdir/creatools_source
   mkdir -p $generationdir/creatools_bin
fi

cd $generationdir

# --------------------------------
#         start_point = 0 : remove everything that was created before
#---------------------------------
if [ $start_point -le 0 ]
then
# the following stupid test is used at debug time; Please don't remove!
#if [ true = false ]
if [ true = true ]
then
  rm -rf creatools_source
  rm -rf creatools_bin
  rm -rf ci
  mkdir -p $generationdir/creatools_source
fi
fi

# ----------------------------------
#         start_point =  1 : Load all sources
#-----------------------------------


if [ $start_point -le 1 ]
then
   if [ true = true ]
   #if [ true = false ]
   then
#
      if [ $sourcesFrom = GIT ] || [ $sourcesFrom = GIT-READ-ONLY ];
      then
		 ssh-add
         bash $scriptDir/gitclone.sh $creasource                   $generationdir	$sourcesFrom
         bash $scriptDir/gitclone.sh $bbtksource                   $generationdir	$sourcesFrom
         bash $scriptDir/gitclone.sh $creavtksource       	       $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $creamaracassource            $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $creaenvironmentsource        $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $creabrukersource             $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $creaimagesource              $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $creacontourssource           $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $crearigidregistrationssource $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $bbtkgeditorsource            $generationdir	$sourcesFrom 
         bash $scriptDir/gitclone.sh $creatoolssource              $generationdir	$sourcesFrom
         bash $scriptDir/gitclone.sh $creaminitoolssource          $generationdir	$sourcesFrom
         bash $scriptDir/gitclone.sh $creatoolstoolssource         $generationdir	$sourcesFrom
 #       bash $scriptDir/cvscheckout.sh $libidosource-ESRF         $generationdir   $cvsUserName
 #	 mv $libidosource-ESRF $libidosource	 	 
          
         cd $generationdir/creatools_source/$creasource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$bbtksource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creavtksource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creamaracassource
		 git checkout vtk9itk5wx3-macos
		 cd $generationdir/creatools_source/$creabrukersource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creaimagesource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creacontourssource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$crearigidregistrationssource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$bbtkgeditorsource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creatoolssource
		 git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creaenvironmentsource
         git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creaminitoolssource
         git checkout vtk9itk5wx3-macos
         cd $generationdir/creatools_source/$creatoolstoolssource
         git checkout vtk9itk5wx3-macos
      fi

      if [ $sourcesFrom = HTML ]
      then
         cd $generationdir/creatools_source
         wwwtargz=http://www.creatis.insa-lyon.fr/software/public/creatools/creaTools/nightly/
         wget $wwwtargz/crea.tgz
         wget $wwwtargz/bbtk.tgz
         wget $wwwtargz/creaVtk.tgz
         wget $wwwtargz/creaMaracasVisu.tgz
         wget $wwwtargz/creaEnvironment.tgz
         wget $wwwtargz/creaBruker.tgz
         wget $wwwtargz/creaImageIO.tgz
         wget $wwwtargz/creaContours.tgz
         wget $wwwtargz/creaRigidRegistration.tgz
         wget $wwwtargz/bbtkGEditor.tgz
         wget $wwwtargz/creaTools.tgz
         wget $wwwtargz/creaMiniTools.tgz
	 
 if [ $OperatingSystem = "MacOS" ]
 then	 	 	    	 
         curl $wwwtargz/crea.tgz
         curl $wwwtargz/bbtk.tgz
         curl $wwwtargz/creaVtk.tgz
         curl $wwwtargz/creaMaracasVisu.tgz
         curl $wwwtargz/creaEnvironment.tgz
         curl $wwwtargz/creaBruker.tgz
         curl $wwwtargz/creaImageIO.tgz
         curl $wwwtargz/creaContours.tgz
         curl $wwwtargz/creaRigidRegistration.tgz
         curl $wwwtargz/bbtkGEditor.tgz
         curl $wwwtargz/creaTools.tgz
         curl $wwwtargz/creaMiniTools.tgz
 else	 
         tar xvzf crea.tgz
         tar xvzf bbtk.tgz
         tar xvzf creaVtk.tgz
         tar xvzf creaMaracasVisu.tgz
         tar xvzf creaEnvironment.tgz	 	 
         tar xvzf creaBruker.tgz
         tar xvzf creaImageIO.tgz
         tar xvzf creaContours.tgz
         tar xvzf creaRigidRegistration.tgz
         tar xvzf bbtkGEditor.tgz
         tar xvzf creaTools.tgz
         tar xvzf creaMiniTools.tgz
fi
         rm -f *.tgz
      fi
   fi
fi
